==> haskell-byteable-0.1.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: byteable
version: 0.1.1
id: byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
key: byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-byteable
synopsis: Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes
    .
    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.
    .
    Usual definition of those types are of the form: newtype MyType = MyType ByteString
category: Data
abi: cdb4e7359967ea10cd00ae1d3fab6945
exposed: True
exposed-modules:
    Data.Byteable
import-dirs: /usr/lib/ghc-8.4.3/site-local/byteable-0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-byteable
hs-libraries: HSbyteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html: /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byteable-0.1.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: byteable
version: 0.1.1
id: byteable-0.1.1-9guyEXUUK503mzSnI32g2S
key: byteable-0.1.1-9guyEXUUK503mzSnI32g2S
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-byteable
synopsis: Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes
    .
    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.
    .
    Usual definition of those types are of the form: newtype MyType = MyType ByteString
category: Data
abi: 07f213671121cb7afb60cc234e4c5068
exposed: True
exposed-modules:
    Data.Byteable
import-dirs: /usr/lib/ghc-8.6.1/site-local/byteable-0.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-byteable
hs-libraries: HSbyteable-0.1.1-9guyEXUUK503mzSnI32g2S
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html: /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
